pyesmda.compute\_ensemble\_average\_normalized\_objective\_function
===================================================================

.. currentmodule:: pyesmda

.. autofunction:: compute_ensemble_average_normalized_objective_function